``zope.annotation`` README
==========================

.. image:: https://img.shields.io/pypi/v/zope.annotation.svg
    :target: https://pypi.python.org/pypi/zope.annotation/
    :alt: Latest Version

.. image:: https://travis-ci.org/zopefoundation/zope.annotation.svg?branch=master
        :target: https://travis-ci.org/zopefoundation/zope.annotation

.. image:: https://readthedocs.org/projects/zopeannotation/badge/?version=latest
        :target: http://zopeannotation.readthedocs.org/en/latest/
        :alt: Documentation Status

This package provides a mechanism to store additional information about
objects without need to modify object class.
